diff --git a/product/ERP5/bootstrap/erp5_core/PortalTypeWorkflowChainTemplateItem/workflow_chain_type.xml b/product/ERP5/bootstrap/erp5_core/PortalTypeWorkflowChainTemplateItem/workflow_chain_type.xml
index d5f0d063618dcccb948c76af31c3d63380e41500..f9db7f1c798f2fe9b25967c220ac4254b71c804d 100644
--- a/product/ERP5/bootstrap/erp5_core/PortalTypeWorkflowChainTemplateItem/workflow_chain_type.xml
+++ b/product/ERP5/bootstrap/erp5_core/PortalTypeWorkflowChainTemplateItem/workflow_chain_type.xml
@@ -73,7 +73,7 @@
  </chain>
  <chain>
   <type>Component Tool</type>
-  <workflow>component_interaction_workflow</workflow>
+  <workflow>dynamic_class_generation_interaction_workflow</workflow>
  </chain>
  <chain>
   <type>Content Existence Constraint</type>
@@ -89,7 +89,7 @@
  </chain>
  <chain>
   <type>Document Component</type>
-  <workflow>component_interaction_workflow, component_validation_workflow, edit_workflow</workflow>
+  <workflow>component_validation_workflow, dynamic_class_generation_interaction_workflow, edit_workflow</workflow>
  </chain>
  <chain>
   <type>Dynamic Category Property</type>
@@ -97,7 +97,7 @@
  </chain>
  <chain>
   <type>Extension Component</type>
-  <workflow>component_interaction_workflow, component_validation_workflow, edit_workflow</workflow>
+  <workflow>component_validation_workflow, dynamic_class_generation_interaction_workflow, edit_workflow</workflow>
  </chain>
  <chain>
   <type>Mapped Value</type>
diff --git a/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/component_interaction_workflow.xml b/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/component_interaction_workflow.xml
deleted file mode 100644
index c88bfa23e821176722db9d563c4fe9b73b14bfae..0000000000000000000000000000000000000000
--- a/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/component_interaction_workflow.xml
+++ /dev/null
@@ -1,46 +0,0 @@
-<?xml version="1.0"?>
-<ZopeData>
-  <record id="1" aka="AAAAAAAAAAE=">
-    <pickle>
-      <global name="InteractionWorkflowDefinition" module="Products.ERP5.InteractionWorkflow"/>
-    </pickle>
-    <pickle>
-      <dictionary>
-        <item>
-            <key> <string>_objects</string> </key>
-            <value>
-              <tuple/>
-            </value>
-        </item>
-        <item>
-            <key> <string>creation_guard</string> </key>
-            <value>
-              <none/>
-            </value>
-        </item>
-        <item>
-            <key> <string>description</string> </key>
-            <value> <string></string> </value>
-        </item>
-        <item>
-            <key> <string>groups</string> </key>
-            <value>
-              <tuple/>
-            </value>
-        </item>
-        <item>
-            <key> <string>id</string> </key>
-            <value> <string>component_interaction_workflow</string> </value>
-        </item>
-        <item>
-            <key> <string>manager_bypass</string> </key>
-            <value> <int>0</int> </value>
-        </item>
-        <item>
-            <key> <string>title</string> </key>
-            <value> <string>Component Interaction Workflow</string> </value>
-        </item>
-      </dictionary>
-    </pickle>
-  </record>
-</ZopeData>
diff --git a/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/component_interaction_workflow/interactions.xml b/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/component_interaction_workflow/interactions.xml
deleted file mode 100644
index e18bf8cbf778a6808aa24ec39bba4b527d7b1bef..0000000000000000000000000000000000000000
--- a/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/component_interaction_workflow/interactions.xml
+++ /dev/null
@@ -1,28 +0,0 @@
-<?xml version="1.0"?>
-<ZopeData>
-  <record id="1" aka="AAAAAAAAAAE=">
-    <pickle>
-      <global name="Interaction" module="Products.ERP5.Interaction"/>
-    </pickle>
-    <pickle>
-      <dictionary>
-        <item>
-            <key> <string>_mapping</string> </key>
-            <value>
-              <dictionary/>
-            </value>
-        </item>
-        <item>
-            <key> <string>_objects</string> </key>
-            <value>
-              <tuple/>
-            </value>
-        </item>
-        <item>
-            <key> <string>id</string> </key>
-            <value> <string>interactions</string> </value>
-        </item>
-      </dictionary>
-    </pickle>
-  </record>
-</ZopeData>
diff --git a/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/component_interaction_workflow/scripts.xml b/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/component_interaction_workflow/scripts.xml
deleted file mode 100644
index 072c8f6540c07806bee17a34c920ec09b2de1bd5..0000000000000000000000000000000000000000
--- a/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/component_interaction_workflow/scripts.xml
+++ /dev/null
@@ -1,28 +0,0 @@
-<?xml version="1.0"?>
-<ZopeData>
-  <record id="1" aka="AAAAAAAAAAE=">
-    <pickle>
-      <global name="Scripts" module="Products.DCWorkflow.Scripts"/>
-    </pickle>
-    <pickle>
-      <dictionary>
-        <item>
-            <key> <string>_mapping</string> </key>
-            <value>
-              <dictionary/>
-            </value>
-        </item>
-        <item>
-            <key> <string>_objects</string> </key>
-            <value>
-              <tuple/>
-            </value>
-        </item>
-        <item>
-            <key> <string>id</string> </key>
-            <value> <string>scripts</string> </value>
-        </item>
-      </dictionary>
-    </pickle>
-  </record>
-</ZopeData>
diff --git a/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/component_interaction_workflow/variables.xml b/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/component_interaction_workflow/variables.xml
deleted file mode 100644
index 6ae03699d19840ac42b097dfc0a5f34edd416170..0000000000000000000000000000000000000000
--- a/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/component_interaction_workflow/variables.xml
+++ /dev/null
@@ -1,22 +0,0 @@
-<?xml version="1.0"?>
-<ZopeData>
-  <record id="1" aka="AAAAAAAAAAE=">
-    <pickle>
-      <global name="Variables" module="Products.DCWorkflow.Variables"/>
-    </pickle>
-    <pickle>
-      <dictionary>
-        <item>
-            <key> <string>_mapping</string> </key>
-            <value>
-              <dictionary/>
-            </value>
-        </item>
-        <item>
-            <key> <string>id</string> </key>
-            <value> <string>variables</string> </value>
-        </item>
-      </dictionary>
-    </pickle>
-  </record>
-</ZopeData>
diff --git a/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/component_interaction_workflow/worklists.xml b/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/component_interaction_workflow/worklists.xml
deleted file mode 100644
index c3432aa051eac2d67ec0692a384adb38d1b6bac8..0000000000000000000000000000000000000000
--- a/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/component_interaction_workflow/worklists.xml
+++ /dev/null
@@ -1,22 +0,0 @@
-<?xml version="1.0"?>
-<ZopeData>
-  <record id="1" aka="AAAAAAAAAAE=">
-    <pickle>
-      <global name="Worklists" module="Products.DCWorkflow.Worklists"/>
-    </pickle>
-    <pickle>
-      <dictionary>
-        <item>
-            <key> <string>_mapping</string> </key>
-            <value>
-              <dictionary/>
-            </value>
-        </item>
-        <item>
-            <key> <string>id</string> </key>
-            <value> <string>worklists</string> </value>
-        </item>
-      </dictionary>
-    </pickle>
-  </record>
-</ZopeData>
diff --git a/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/component_interaction_workflow/interactions/ComponentTool_reset.xml b/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/dynamic_class_generation_interaction_workflow/interactions/ComponentTool_reset.xml
similarity index 93%
rename from product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/component_interaction_workflow/interactions/ComponentTool_reset.xml
rename to product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/dynamic_class_generation_interaction_workflow/interactions/ComponentTool_reset.xml
index 3e783f502e4ea87b294bfe573298b93e4e353b05..06e3901c10b46307173e15409ca42eb4a5c6394b 100644
--- a/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/component_interaction_workflow/interactions/ComponentTool_reset.xml
+++ b/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/dynamic_class_generation_interaction_workflow/interactions/ComponentTool_reset.xml
@@ -34,13 +34,13 @@
             <key> <string>before_commit_script_name</string> </key>
             <value>
               <list>
-                <string>reset</string>
+                <string>ComponentTool_reset</string>
               </list>
             </value>
         </item>
         <item>
             <key> <string>description</string> </key>
-            <value> <string></string> </value>
+            <value> <string>When a Component is deleted or added in Component Tool, reset all Components</string> </value>
         </item>
         <item>
             <key> <string>guard</string> </key>
diff --git a/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/component_interaction_workflow/interactions/Component_modify.xml b/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/dynamic_class_generation_interaction_workflow/interactions/Component_modify.xml
similarity index 93%
rename from product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/component_interaction_workflow/interactions/Component_modify.xml
rename to product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/dynamic_class_generation_interaction_workflow/interactions/Component_modify.xml
index c466dede0670c145b699aabf3f4d4685d05713ca..80ceb9c27de06660eaf9aa5ecc66edf886db9f6b 100644
--- a/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/component_interaction_workflow/interactions/Component_modify.xml
+++ b/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/dynamic_class_generation_interaction_workflow/interactions/Component_modify.xml
@@ -40,7 +40,7 @@
         </item>
         <item>
             <key> <string>description</string> </key>
-            <value> <string></string> </value>
+            <value> <string>Before the reference, version or source code of a Component is modified, the Component is set to modified state, and at the end if the Consistency checks do not return any error, it is set to validated state. </string> </value>
         </item>
         <item>
             <key> <string>guard</string> </key>
diff --git a/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/component_interaction_workflow/interactions/Component_reset.xml b/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/dynamic_class_generation_interaction_workflow/interactions/Component_reset.xml
similarity index 93%
rename from product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/component_interaction_workflow/interactions/Component_reset.xml
rename to product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/dynamic_class_generation_interaction_workflow/interactions/Component_reset.xml
index 5a7f0c8023b85a51e3735b6a8d13bb8a5e828f03..bf5af951929c8cf87073c00599430a5017eb32bf 100644
--- a/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/component_interaction_workflow/interactions/Component_reset.xml
+++ b/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/dynamic_class_generation_interaction_workflow/interactions/Component_reset.xml
@@ -34,13 +34,13 @@
             <key> <string>before_commit_script_name</string> </key>
             <value>
               <list>
-                <string>reset</string>
+                <string>ComponentTool_reset</string>
               </list>
             </value>
         </item>
         <item>
             <key> <string>description</string> </key>
-            <value> <string></string> </value>
+            <value> <string>When a Component is validated or invalidated, all loaded Components are reset</string> </value>
         </item>
         <item>
             <key> <string>guard</string> </key>
diff --git a/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/component_interaction_workflow/scripts/reset.xml b/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/dynamic_class_generation_interaction_workflow/scripts/ComponentTool_reset.xml
similarity index 97%
rename from product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/component_interaction_workflow/scripts/reset.xml
rename to product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/dynamic_class_generation_interaction_workflow/scripts/ComponentTool_reset.xml
index ea84afb38d063bd461dc18aad6ed8f506563aa8f..10b247176a3020924200dd62e84d21e785ab0e24 100644
--- a/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/component_interaction_workflow/scripts/reset.xml
+++ b/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/dynamic_class_generation_interaction_workflow/scripts/ComponentTool_reset.xml
@@ -67,7 +67,7 @@
         </item>
         <item>
             <key> <string>id</string> </key>
-            <value> <string>reset</string> </value>
+            <value> <string>ComponentTool_reset</string> </value>
         </item>
       </dictionary>
     </pickle>
diff --git a/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/component_interaction_workflow/scripts/Component_setModifiedState.xml b/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/dynamic_class_generation_interaction_workflow/scripts/Component_setModifiedState.xml
similarity index 100%
rename from product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/component_interaction_workflow/scripts/Component_setModifiedState.xml
rename to product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/dynamic_class_generation_interaction_workflow/scripts/Component_setModifiedState.xml
diff --git a/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/component_interaction_workflow/scripts/Component_validateAfterModified.xml b/product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/dynamic_class_generation_interaction_workflow/scripts/Component_validateAfterModified.xml
similarity index 100%
rename from product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/component_interaction_workflow/scripts/Component_validateAfterModified.xml
rename to product/ERP5/bootstrap/erp5_core/WorkflowTemplateItem/portal_workflow/dynamic_class_generation_interaction_workflow/scripts/Component_validateAfterModified.xml
diff --git a/product/ERP5/bootstrap/erp5_core/bt/change_log b/product/ERP5/bootstrap/erp5_core/bt/change_log
index a0ddff18db7b1b13c954d57dac8f4d0750afbc22..14922b5bdfbba865f60d59a386bdf1142ba1f346 100644
--- a/product/ERP5/bootstrap/erp5_core/bt/change_log
+++ b/product/ERP5/bootstrap/erp5_core/bt/change_log
@@ -1,3 +1,6 @@
+2012-02-25 arnaud.fontaine
+* Merge component_interaction_workflow into dynamic_class_generation_interaction_workflow.
+
 2012-02-25 arnaud.fontaine
 * Remove useless DocumentConstraint Property Sheet for Document Component.
 
diff --git a/product/ERP5/bootstrap/erp5_core/bt/revision b/product/ERP5/bootstrap/erp5_core/bt/revision
index 3c537a41c7e981fba610ca531c8ddc2c536ee1d4..ed2b1b0dcc5b84f3bcafaceb02d218dd22fe0540 100644
--- a/product/ERP5/bootstrap/erp5_core/bt/revision
+++ b/product/ERP5/bootstrap/erp5_core/bt/revision
@@ -1 +1 @@
-41008
\ No newline at end of file
+41009
\ No newline at end of file
diff --git a/product/ERP5/bootstrap/erp5_core/bt/template_portal_type_workflow_chain_list b/product/ERP5/bootstrap/erp5_core/bt/template_portal_type_workflow_chain_list
index 502ca25d37aba3978faf3f3c9d7f45f0f16567fa..bd4afe30bf535ea3201bf505f42e9c095abc8cf9 100644
--- a/product/ERP5/bootstrap/erp5_core/bt/template_portal_type_workflow_chain_list
+++ b/product/ERP5/bootstrap/erp5_core/bt/template_portal_type_workflow_chain_list
@@ -19,16 +19,16 @@ Category Related Membership Arity Constraint | dynamic_class_generation_interact
 Category Related Membership State Constraint | dynamic_class_generation_interaction_workflow
 Category Tool | dynamic_class_generation_interaction_workflow
 Category | edit_workflow
-Component Tool | component_interaction_workflow
+Component Tool | dynamic_class_generation_interaction_workflow
 Content Existence Constraint | dynamic_class_generation_interaction_workflow
 Distributed Ram Cache | distributed_ram_cache_interaction_workflow
-Document Component | component_interaction_workflow
 Document Component | component_validation_workflow
+Document Component | dynamic_class_generation_interaction_workflow
 Document Component | edit_workflow
 Document | edit_workflow
 Dynamic Category Property | dynamic_class_generation_interaction_workflow
-Extension Component | component_interaction_workflow
 Extension Component | component_validation_workflow
+Extension Component | dynamic_class_generation_interaction_workflow
 Extension Component | edit_workflow
 Mapped Value | edit_workflow
 Memcached Plugin | memcached_plugin_interaction_workflow
diff --git a/product/ERP5/bootstrap/erp5_core/bt/template_workflow_id_list b/product/ERP5/bootstrap/erp5_core/bt/template_workflow_id_list
index 7561cfa7ee55345b2769e59344df4f8de39a55a0..11778b697ecd6c3e05e36ea9d9d9486cc168e562 100644
--- a/product/ERP5/bootstrap/erp5_core/bt/template_workflow_id_list
+++ b/product/ERP5/bootstrap/erp5_core/bt/template_workflow_id_list
@@ -1,7 +1,6 @@
 base_type_interaction_workflow
 business_template_building_workflow
 business_template_installation_workflow
-component_interaction_workflow
 component_validation_workflow
 distributed_ram_cache_interaction_workflow
 dynamic_class_generation_interaction_workflow
diff --git a/product/ERP5Type/mixin/component.py b/product/ERP5Type/mixin/component.py
index 96e6f196251394b00dcc55d1fc865fa0d17fc96f..a692846385d3de9adcd870cb0aa29873cc300600 100644
--- a/product/ERP5Type/mixin/component.py
+++ b/product/ERP5Type/mixin/component.py
@@ -62,11 +62,12 @@ class RecordablePropertyMetaClass(ExtensionClass):
         """
         Everytime either 'reference', 'version' or 'text_content' are modified
         when a Component is in modified or validated state, the Component is
-        set to modified state by component interaction workflow, then in this
-        method, the current property value is recorded in order to handle any
-        error returned when checking consistency before the new value is
-        set. At the end, through component interaction workflow, the Component
-        is validated only if checkConsistency returns no error
+        set to modified state by dynamic class generation interaction
+        workflow, then in this method, the current property value is recorded
+        in order to handle any error returned when checking consistency before
+        the new value is set. At the end, through dynamic class generation
+        interaction workflow, the Component is validated only if
+        checkConsistency returns no error
 
         The recorded property will be used upon loading the Component whereas
         the new value set is displayed in Component view.